package com.god.base.common.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.god.base.common.domain.request.FenceAddRequest;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Date;

/**
 * 电子围栏信息
 *
 * @author Lou-Zs
 * @Date 2023/11/20 19:41
 **/
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@TableName(value = "t_fence")
public class Fence {


    /**
     * 围栏主建编号
     */
    @TableId(value = "fence_id",type = IdType.AUTO)
    private Integer fenceId;

    /**
     * 围栏名称
     */
    @NotEmpty(message = "围栏名称不能为空")
    private String fenceName;

    /**
     * 围栏坐标位置
     */
    private String fenceLocation;

    /**
     * 激活状态
     * 0-停用
     * 1-开启
     */
    private Integer fenceStatus;

    /**
     * 行驶状态
     * 1-驶入
     * 2-驶出
     */
    private Integer driveStatus;

    /**
     * 车辆主建
     */
    private String carVinId;

    /**
     * 创建时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH-mm-ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH-mm-ss",timezone = "GMT+8")
    private Date createTime;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH-mm-ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH-mm-ss",timezone = "GMT+8")
    private Date updateTime;



    public static Fence fenceBuildAdd(FenceAddRequest fenceAddRequest){
            return Fence.builder()
                    .fenceName(fenceAddRequest.getFenceName())
                    .fenceLocation(fenceAddRequest.getFenceLocation())
                    .fenceStatus(fenceAddRequest.getFenceStatus())
                    .driveStatus(fenceAddRequest.getDriveStatus())
                    .carVinId(fenceAddRequest.getCarVinId())
                    .createTime(fenceAddRequest.getCreateTime())
                    .updateTime(fenceAddRequest.getUpdateTime())
                    .build();
    }

}
