package com.god.base.server.common.domain;

import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.god.base.server.common.domain.request.CarRequest;
import com.god.common.core.annotation.Excel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;

/**
 * 车辆信息管理对象
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@TableName(value = "t_car")
public class Car  {

    private static final long serialVersionUID = 1L;

    /**
     * 车辆Vin 主键
     */
    @Excel(name = "车辆carVibId")
    private String carVinId;
    /**
     * 单位id
     */
    private long userId;
    /**
     * 车辆类型id
     */
    @Excel(name = "车辆类型ID")
    private long carTypeId;
    /**
     * 电池箱信息id
     */
    private long batteryBoxId;
    /**
     * 电池组id
     */
    private long cellId;
    /**
     * 单体电池id
     */
    private long batteryCellId;
    /**
     * 电池组模块id
     */
    private long batteryPackInformationId;
    /**
     * 电子围栏ID
     */
    @Excel(name = "电子围栏ID")
    private long fenceId;
    /**
     * 车牌号
     */
    private String carNumber;
    /**
     * 驱动机主键
     */
    private long driveMotorId;
    /**
     * 车辆总里程
     */
    private String carMileage;
    /**
     * 创建者
     */
    private String createBy;
    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "开始时间" , width = 30, dateFormat = "yyyy-MM-dd")
    private Date createTime;
    /**
     * 更新者
     */
    private String updateBy;
    /**
     * 更新时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "结束时间" , width = 30, dateFormat = "yyyy-MM-dd")
    private Date updateTime;
    /**
     * 区域
     */
    private String address;
    /**
     * 电池厂商
     */
    @Excel(name = "电池厂商")
    private String batteryManufacturer;
    /**
     * 电机厂商
     */
    @Excel(name = "电机厂商")
    private String motorManufacturer;
    /**
     * 电机编号
     */
    @Excel(name = "电机编号")
    private String motorNumber;
    /**
     * 电池编号
     */
    @Excel(name = "电池编号")
    private String batteryNumber;
    /**
     * 逻辑删除
     */
    private int isDelete;
    /**
     * 车辆状态
     */
    @Excel(name = "车辆状态")
    private int status;

    /**
     * 电子围栏名称
     */
    private String fenceName;
    /**
     * 车辆类型名称
     */
    private String carTypeName;

    public static Car carBuildAdd(CarRequest carRequest){
        return Car.builder()
                .carVinId(carRequest.getCarVinId())
                .carTypeId(carRequest.getCarTypeId())
                .fenceId(carRequest.getFenceId())
                .status(carRequest.getStatus())
                .batteryManufacturer(carRequest.getBatteryManufacturer())
                .motorManufacturer(carRequest.getMotorManufacturer())
                .motorNumber(carRequest.getMotorNumber())
                .batteryNumber(carRequest.getBatteryNumber())
                .build();
    }

}
