package com.god.base.server.controller;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.nacos.api.model.v2.Result;
import com.god.base.common.domain.Breakdown;
import com.god.base.common.domain.request.BreakdownRequest;
import com.god.base.server.service.BreakdownService;
import com.god.common.core.web.page.TableDataInfo;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 车辆故障码controller
 *
 * @author ChenXinHai
 * @version 2023/11/20 - 19:31
 */
@RestController
@RequestMapping("/Breakdown")
@Log4j2
public class BreakdownController {
    @Autowired
    private BreakdownService breakdownService;
    @Autowired
    private HttpServletRequest request;

    /**
     * 故障日志表
     * @param breakdownRequest
     * @return
     */
    @GetMapping("/list")
    public Result<TableDataInfo<Breakdown>> breakdownList(@RequestBody BreakdownRequest breakdownRequest){
        log.info("功能介绍:查询车辆故障码列表,请求方式:{},请求路径:{},请求参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(breakdownRequest));
        //分页查询列表
        TableDataInfo<Breakdown> dataInfo = breakdownService.breakdownList(breakdownRequest);
        return Result.success(dataInfo);
    }


    /**
     * 添加故障信息表
     * @param breakdownRequest
     * @return
     */
    @PostMapping("/breakdownAdd")
    public Result<String> breakdownAdd(@RequestBody @Validated BreakdownRequest breakdownRequest){
        log.info("功能介绍新增故障信息,请求方式;{},请求路径:{},请求参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(breakdownRequest));

        //故障信息添加
        breakdownService.save(Breakdown.addReqBuild(breakdownRequest));

        return Result.success();
    }


    /**
     * 根据故障表编辑故障信息
     * @param breakdown
     * @return
     */
    @PostMapping("/breakdownUpdate")
    public Result<String> breakdownUpdate(@RequestBody @Validated Breakdown breakdown){
        log.info("功能介绍:编辑故障信息,请求方式:{},请求路径:{},请求参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(breakdown));

        //编辑故障信息
        breakdownService.updateById(breakdown);

        return Result.success();
    }


    /**
     * 根据故障编号删除故障
     * @param id
     * @return
     */
    @GetMapping("/breakdownDelete")
    public Result<String> breakdownDelete(@RequestParam("id") Integer id){
        log.info("功能介绍:通过故障编号删除故障,请求方式:{},请求路径:{},请求参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(id));

        //根据故障编号删除故障
        breakdownService.removeById(id);
        return Result.success();
    }




}
