package com.god.base.server.controller;

import com.alibaba.fastjson.JSONObject;
import com.god.base.server.common.domain.Car;
import com.god.base.server.common.domain.VehicleMessage;
import com.god.base.server.common.domain.request.CarRequest;
import com.god.base.server.service.CarService;
import com.god.base.server.util.AopConfig;
import com.god.common.core.domain.Result;
import com.god.common.core.utils.poi.ExcelUtil;
import com.god.common.core.web.controller.BaseController;
import com.god.common.core.web.page.TableDataInfo;
import com.god.common.log.annotation.Log;
import com.god.common.log.enums.BusinessType;
import com.god.common.security.annotation.RequiresPermissions;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 车辆管理
 */
@RestController
@RequestMapping("/car")
@Log4j2
public class CarController extends BaseController {

    @Autowired
    private HttpServletRequest request; // 用于获取方法执行信息

    @Autowired
    private CarService carService;

    @Autowired
    private AopConfig aopConfig;


    /**
     * 查询车辆信息管理列表
     */
    @RequiresPermissions
    @GetMapping("/list")
    public Result<TableDataInfo<Car>> list(@RequestBody CarRequest carRequest){

        startPage();//设置请求分页数据
        List<Car> list = carService.selectCarInfoList(carRequest);

        return getDataTable(list);
    }

    /**
     * 车辆信息查看
     */
    @GetMapping("carList/{userId}")
    public Result<?> carList(@PathVariable String userId){

        log.info("功能介绍车辆信息列表查看,请求方式:{},请求路径:{},请求参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(userId));

        startPage();//设置请求分页数据 继承方法
        Result<List<Car>> carList = carService.carList(userId);

        log.info("功能介绍车辆信息列表查看,响应方式:{},响应路径:{},响应参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(carList));

        return Result.success(carList);
    }


    /**
     * 添加车辆管理信息
     */
    @Log(title = "车辆信息管理" , businessType = BusinessType.INSERT) // 添加
    @PostMapping("/addCar")
    public Result<String> addCarP(@RequestBody @Validated CarRequest carRequest){

        carService.save(Car.carBuildAdd(carRequest));

        return Result.success();
    }

    /**
     * 修改车辆信息
     */
    @Log(title = "车辆信息管理" , businessType = BusinessType.UPDATE) //修改
    @PostMapping("/updCar")
    public Result<Car> updCar(@PathVariable @Validated Car car){
        log.info("功能介绍修改车辆,请求方式:{},请求路径:{},请求参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(car));

        carService.updateById(car);

        log.info("功能介绍修改车辆,响应方式:{},响应路径:{},响应参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(car));

        return Result.success();
    }

    /**
     * 逻辑删除车辆信息管理
     */
    @Log(title = "车辆信息管理" , businessType = BusinessType.DELETE) // 删除
    @DeleteMapping("/delCar/{vinId}")
    public Result delCar(@PathVariable String vinId){
        log.info("功能介绍逻辑删除车辆信息,请求方式:{},请求路径:{},请求参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(vinId));

        boolean b = carService.removeById(vinId);

        log.info("功能介绍逻辑删除车辆信息,响应方式:{},响应路径:{},响应参数:{}",
                request.getMethod(),
                request.getRequestURL(),
                JSONObject.toJSONString(b));

        return Result.success();
    }

    /**
     * 导出车辆信息管理列表
     */
    @RequiresPermissions("car:car:export")
    @Log(title = "车辆信息管理" , businessType = BusinessType.EXPORT) // 导出 跳转业务操作类型表中
    @PostMapping("/export")
    public void export(HttpServletResponse response , Car car , CarRequest carRequest)
    {
        List<Car> list = carService.selectCarInfoList(carRequest);
        ExcelUtil<Car> util = new ExcelUtil<>(Car.class);
        //对list数据源将其里面的数据导入到excel表单
        util.exportExcel(response,list,"车辆信息管理");
    }


    /**
     * 获取所有在线车辆
     */
    @GetMapping("/onlineVehicle")
    public Result<List<VehicleMessage>> onlineVehicle(){
        return carService.onlineVehicle();
    }

    /**
     * 统计车辆
     */
    @GetMapping("/countData")
    public Result<String> countData(){
        return carService.countData();
    }


}
