package com.god.base.server.controller;

import com.god.base.server.common.domain.DrivingRecord;
import com.god.base.server.common.domain.VehicleMessage;
import com.god.base.server.service.IDrivingRecordService;
import com.god.common.core.domain.Result;
import com.god.common.core.utils.poi.ExcelUtil;
import com.god.common.core.web.controller.BaseController;
import com.god.common.core.web.page.TableDataInfo;
import com.god.common.log.annotation.Log;
import com.god.common.log.enums.BusinessType;
import com.god.common.security.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * 车辆行驶记录 DrivingRecordController
 */
@RestController
@RequestMapping("/record")
public class DrivingRecordController extends BaseController {

    @Autowired
    private IDrivingRecordService drivingRecordService;

    /**
     * 查询车辆行驶记录
     *
     * @param drivingRecord
     * @return
     */
    @RequiresPermissions("record:record:list")
    @GetMapping("list")
    public Result<TableDataInfo<DrivingRecord>> list(DrivingRecord drivingRecord){
        //设置请求分页数据
        startPage();
        List<DrivingRecord> list =  drivingRecordService.selectDrivingRecordList(drivingRecord);
        return getDataTable(list);
    }


    /**
     * 导出车辆行驶记录列表
     * @param response
     * @param drivingRecord
     */
    @RequiresPermissions("record:record:export")
    @Log(title = "车辆行驶记录" , businessType = BusinessType.EXPORT) // 导出
    @PostMapping("export")
    public void export(HttpServletResponse response , DrivingRecord drivingRecord)
    {
        List<DrivingRecord> list = drivingRecordService.selectDrivingRecordList(drivingRecord);
        ExcelUtil<DrivingRecord> util = new ExcelUtil<>(DrivingRecord.class);
        //对list数据源将其里面的数据导入到excel表中
        util.exportExcel(response , list , "车辆行驶记录数据");
    }

    /**
     * 获取车辆行驶记录详细信息
     * @param id
     * @return
     */
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id){ //操作信息提醒
        //返回成功数据 | 查询车辆行驶记录
        return Result.success(drivingRecordService.selectDrivingRecordById(id));
    }

    /**
     * 新增车辆行驶记录
     * @param drivingRecord
     * @return
     */
    @RequiresPermissions("record:record:add")
    @Log(title = "车辆行驶记录" , businessType = BusinessType.INSERT) // 新增
    @PostMapping
    public Result add(@RequestBody DrivingRecord drivingRecord){
        //响应返回结果 | 新增车辆行驶记录
        return Result.success(drivingRecordService.insertDrivingRecord(drivingRecord));
    }

    /**
     * 修改车辆行驶记录
     * @param drivingRecord
     * @return
     */
    @RequiresPermissions("record:record:edit")
    @Log(title = "车辆行驶记录" , businessType = BusinessType.UPDATE) // 修改
    @PutMapping
    public Result edit(@RequestBody DrivingRecord drivingRecord)
    {
        //响应返回结果 | 修改车辆行驶记录
        return Result.success(drivingRecordService.updateDrivingRecord(drivingRecord));
    }


    /**
     * 车辆行驶记录的批量删除
     * @param ids
     * @return
     */
    @RequiresPermissions("record:record:remove")
    @Log(title = "车辆行驶记录" , businessType = BusinessType.DELETE) // 删除
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        //响应返回结果 | 批量删除车辆行驶记录
        return Result.success(drivingRecordService.deleteDrivingRecordByIds(ids));
    }

    /**
     * 添加车辆行驶记录
     * @param vin
     * @return
     */
    @PostMapping("/strtVehocle/{vin}")
    public Result startVehicle(@PathVariable("vin") String vin){
        DrivingRecord drivingRecord = new DrivingRecord();
        drivingRecord.setVin(vin);
        drivingRecord.setStartTime(new Date());
        drivingRecordService.insertDrivingRecord(drivingRecord);
        return Result.success();
    }

    /**
     * 获取单条记录
     * @param id
     * @return
     */
    @GetMapping("/findOne/{id}")
    public Result<DrivingRecord> findOne(@PathVariable("id") Long id){
        DrivingRecord drivingRecord = drivingRecordService.selectDrivingRecordById(id);
        return Result.success(drivingRecord);
    }

    /**
     * 回显历史轨迹
     * @param id
     * @return
     */
    @GetMapping("trackHistory/{id}")
    public Result<List<VehicleMessage>> trackHistory(@PathVariable Long id){
        return null;
    }


}































