package com.god.base.server.controller;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.nacos.api.model.v2.Result;
import com.god.base.common.domain.Fault;
import com.god.base.common.domain.request.FaultRequest;
import com.god.base.server.service.FaultService;
import com.god.common.core.web.controller.BaseController;
import com.god.common.core.web.page.TableDataInfo;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 故障表
 *
 * @author ChenXinHai
 * @version 2023/11/21 - 18:33
 */
@RestController
@RequestMapping("/fault")
@Log4j2
public class FaultController extends BaseController {
    @Autowired
    private FaultService faultService;
    @Autowired
    private HttpServletRequest request;
    @GetMapping("list")
    public Result<TableDataInfo<Fault>> faultList(@RequestBody @Validated FaultRequest faultRequest){
        log.info("功能介绍:查询车辆故障码列表,请求方式:{},请求路径:{},请求参数:{}",
                request.getRequestURL(),
                request.getMethod(),
                JSONObject.toJSONString(faultRequest));
        //分页查询列表
        TableDataInfo<Fault> dataInfo = faultService.faultList(faultRequest);
        return Result.success(dataInfo);
    }

    /**
     * 添加故障
     * @param faultRequest
     * @return
     */
    @PostMapping("/faultAdd")
    public Result<String> faultAdd(@RequestBody @Validated FaultRequest faultRequest){
        log.info("功能介绍:添加车辆故障,请求方式:{},请求路径:{},请求参数:{}",
                request.getRequestURI(),
                request.getMethod(),
                JSONObject.toJSONString(faultRequest));
        faultService.save(Fault.addFault(faultRequest));
        return Result.success();
    }

    /**
     * 修改故障
     * @param fault
     * @return
     */
    @PostMapping("/faultUpdate")
    public Result<String> faultUpdate(@RequestBody @Validated Fault fault){
        log.info("功能介绍:修改车辆故障,请求方式:{},请求路径:{},请求参数:{}",
                request.getRequestURI(),
                request.getMethod(),
                JSONObject.toJSONString(fault));
        faultService.updateById(fault);
        return Result.success();
    }


    @PostMapping("/faultDelete")
    public Result<String> faultDelete(@RequestParam("faultId") Integer faultId){
        log.info("功能介绍:删除车辆故障,请求方式:{},请求路径:{},请求参数:{}",
                request.getRequestURI(),
                request.getMethod(),
                JSONObject.toJSONString(faultId));
        // 根据故障id删除故障
        faultService.removeById(faultId);
        return Result.success();
    }

}
