package com.god.base.server.controller;

/**
 * @ClassName FenceController
 * @Author Lou-Zs
 * @Date 2023/11/19 20:00
 * @Version 1.0
 * @Description TODO
 **/

import com.alibaba.fastjson.JSONObject;

import com.god.base.common.domain.Fence;
import com.god.base.common.domain.request.FenceAddRequest;
import com.god.base.common.domain.request.FenceQueryRequest;
import com.god.base.server.service.FenceService;
import com.god.common.core.web.page.TableDataInfo;
import com.god.common.log.annotation.Log;
import com.god.common.log.enums.BusinessType;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.god.common.core.domain.Result;
import javax.servlet.http.HttpServletRequest;
/**
 * base围栏操作
 * @author Lou-Zs
 */
@RestController
@RequestMapping("/baseFence")
@Log4j2
public class FenceController {

    @Autowired
    private HttpServletRequest request;
    @Autowired
    private FenceService fenceService;


    /**
     * 增添电子围栏
     * @param fenceAddRequest
     * @return
     */
    @PostMapping("/insertFence")
    @Log(title = "添加围栏", businessType = BusinessType.INSERT)
    public Result<String> insertFence(@RequestBody @Validated FenceAddRequest fenceAddRequest){
            //围栏添加
            fenceService.save(Fence.fenceBuildAdd(fenceAddRequest));
            return Result.success();
    }


    /**
     * 根据围栏编号编辑围栏信息
     * @param fence
     * @return
     */
    @PostMapping("/updateFence")
    @Log(title = "编辑围栏",businessType = BusinessType.UPDATE)
    public Result<String> updateFence(@RequestBody @Validated Fence fence){
        //编辑电子围栏信息
        fenceService.updateById(fence);

        return Result.success();
    }


    /**
     * 根据围栏编号删除围栏
     * @param fenceId
     * @return
     */
    @GetMapping("/deleteFence")
    @Log(title = "根据围栏编号删除围栏",businessType = BusinessType.DELETE)
    public Result<String> deleteFence(@RequestParam("fenceId") Integer fenceId){
        //根据围栏编号删除围栏
        fenceService.removeById(fenceId);
        return Result.success();
    }


    /**
     * 分页查询电子围栏列表
     * @param fenceQueryRequest
     * @return
     */
    @PostMapping("/fenceListAndPage")
    @Log(title = "查询围栏信息",businessType = BusinessType.FORCE)
    public Result<TableDataInfo<Fence>> fenceListAndPage(@RequestBody FenceQueryRequest fenceQueryRequest){
        //分页查询围栏列表
        TableDataInfo<Fence> dataInfo = fenceService.fenceListAndPage(fenceQueryRequest);
        return Result.success(dataInfo);
    }
}
