package com.god.base.server.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.god.base.common.domain.Breakdown;
import com.god.base.common.domain.request.BreakdownRequest;
import com.god.base.server.mapper.BreakdownMapper;
import com.god.base.server.service.BreakdownService;
import com.god.common.core.web.page.TableDataInfo;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.Serializable;

/**
 * 车辆故障码serviceImpl
 */
@Log4j2
@Service
public class BreakdownServiceImpl extends ServiceImpl<BreakdownMapper, Breakdown> implements BreakdownService {

    @Autowired
    private BreakdownMapper breakdownMapper;


    @Override
    public TableDataInfo<Breakdown> breakdownList(BreakdownRequest breakdownRequest) {
        LambdaQueryWrapper<Breakdown> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        //判断车辆VIN是否为空
        if (StringUtils.isNotEmpty(breakdownRequest.getCarVin())){
            //模糊查询
            lambdaQueryWrapper.like(Breakdown::getCarVin,breakdownRequest.getCarVin());
        }
      if (null!=breakdownRequest.getStatus()){ // 故障码状态
          lambdaQueryWrapper.eq(Breakdown::getStatus,breakdownRequest.getStatus());
      }
        Page<Breakdown> fencePage = breakdownRequest.buildPage();
        log.info("分页查询:[ {} ]", JSONObject.toJSONString(fencePage));
        Page<Breakdown> page = this.page(fencePage,lambdaQueryWrapper);
        return TableDataInfo.<Breakdown>builder()
                .rows(page.getRecords())
                .total(page.getTotal())
                .build();
    }

    @Override
    public boolean save(Breakdown entity) {
        int i = breakdownMapper.insert(entity);
        if (i<1){
            log.warn("增加故障信息:[/-{}-/]失败! 请求参数:{}",
                    entity.getBreadownId(),
                    JSONObject.toJSONString(entity));
            throw new RuntimeException("增添围栏失败!");
        }
        return true;
    }
    @Override
    public boolean removeById(Serializable id) {
        int i = breakdownMapper.deleteById(id);
        if (i<1){
            log.warn("删除故障编号:[/-{}-/]失败!",
                    id);
            throw new RuntimeException("删除故障失败!");
        }
        return true;
    }

    /**
     * 根据故障编号编辑故障信息
     * @param breakdown
     * @return
     */
    @Override
    public boolean updateById(Breakdown breakdown) {
        boolean update = this.updateById(breakdown);
        if (!update){
            log.warn("编辑故障信息[/-{}-/]未成功! 请求参数:{}",
                    breakdown.getBreadownId(),
                    JSONObject.toJSONString(breakdown));
            throw new RuntimeException("编辑故障失败!");
        }
        return true;
    }
}
