package com.god.base.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.god.base.server.common.domain.Car;
import com.god.base.server.common.domain.VehicleMessage;
import com.god.base.server.common.domain.request.CarRequest;
import com.god.base.server.common.domainConstants.RedisConstant;
import com.god.base.server.mapper.CarMapper;
import com.god.base.server.service.CarService;
import com.god.common.core.domain.Result;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 车辆管理业务层
 */
@Log4j2
@Service
public class CarServiceImpl extends ServiceImpl<CarMapper, Car> implements CarService {

    @Autowired
    private CarMapper carMapper;

    @Autowired
    private RedisTemplate redisTemplate;


    /**
     * 车辆信息
     *
     * @param userId
     * @return
     */
    @Override
    public Result<List<Car>> carList(String userId) {
//        Long userId1 = SecurityUtils.getUserId();
//        if (null == userId1){
//            throw new SecurityException("请先登录");
//        }
        int userId1 = 1;
        List<Car> carList = carMapper.getList(userId1);
        return Result.success(carList);
    }


    /**
     * 查询车辆信息管理列表
     *
     * @param carRequest 车辆信息管理
     * @return
     */
    @Override
    public List<Car> selectCarInfoList(CarRequest carRequest) {
        LambdaQueryWrapper<Car> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        //判断vin是否为空
        if (StringUtils.isNotEmpty(carRequest.getCarVinId())){
            //模糊查询 vin
            lambdaQueryWrapper.like(Car::getCarVinId, carRequest.getCarVinId());
        }
            //模糊查询 车辆类型
            lambdaQueryWrapper.like(Car::getCarTypeId, carRequest.getCarTypeId());
            //模糊查询 电子围栏
            lambdaQueryWrapper.like(Car::getFenceId, carRequest.getFenceId());
            //模糊查询 车辆状态
            lambdaQueryWrapper.like(Car::getStatus, carRequest.getStatus());
        if (StringUtils.isNotEmpty(carRequest.getBatteryManufacturer())){
             //模糊查询 电池厂商
             lambdaQueryWrapper.like(Car::getBatteryManufacturer, carRequest.getBatteryManufacturer());
        }
        if (StringUtils.isNotEmpty(carRequest.getMotorManufacturer())){
             //模糊查询 电机厂商
             lambdaQueryWrapper.like(Car::getMotorManufacturer, carRequest.getMotorManufacturer());
        }
        if (StringUtils.isNotEmpty(carRequest.getMotorNumber())){
             //模糊查询 电机编号
             lambdaQueryWrapper.like(Car::getMotorNumber, carRequest.getMotorNumber());
        }
        if (StringUtils.isNotEmpty(carRequest.getBatteryNumber())){
             //模糊查询 电池编号
             lambdaQueryWrapper.like(Car::getBatteryNumber, carRequest.getBatteryNumber());
        }

        return carMapper.selectVehicleInfoList(carRequest);
    }


    /**
     * 根据VIN 编辑管理修改车辆信息数据
     * @param entity
     * @return
     */
    @Override
    public boolean updateById(Car entity) {
        boolean updatedById = super.updateById(entity);
        if (!updatedById){
            throw new RuntimeException("修改失败");
        }
        return true;
    }

    /**
     * 添加车辆管理数据
     * @param entity
     * @return
     */
    @Override
    public boolean save(Car entity) {
        boolean addCar = super.save(entity);
        if (!addCar){
            throw new RuntimeException("添加车辆管理失败失败");
        }
        return true;
    }

    /**
     * 删除车辆信息数据
     *
     * @param id
     * @return
     */
    @Override
    public boolean removeById(Serializable id) {
        boolean remove = super.removeById(id);
        if (!remove) {
            log.warn("删除管理车辆数据:[/-{}-/]失败!", id);
            throw new RuntimeException("删除管理车辆数据失败");
        }
        return true;
    }

    /**
     * 获取所有在线车辆
     * @return
     */
    @Override
    public Result<List<VehicleMessage>> onlineVehicle() {
        List<String> ids = carMapper.getOnlineCarIds();
        List<VehicleMessage> messages = ids.stream().map(id -> {
            VehicleMessage message = (VehicleMessage) redisTemplate.opsForValue().get(RedisConstant.CURRENT_INFO + ":" + id);
            return message;
        }).collect(Collectors.toList());Collectors.toList();
        return Result.success(messages);
    }

    @Override
    public Result<String> countData() {
        Integer day = (Integer) redisTemplate.opsForValue().get(RedisConstant.VEHICLE_INFO_TOKEN+RedisConstant.CURRENT_DAY_FAULT);
        Integer month = (Integer) redisTemplate.opsForValue().get(RedisConstant.VEHICLE_INFO_TOKEN+RedisConstant.CURRENT_MONTH_FAULT);
        Integer onlineCount = carMapper.getOnlineCarCount();
        Integer unOnlineCount = carMapper.getUnOnlineCount();
        return Result.success(day + ":" + month + ":" + onlineCount + ":" + unOnlineCount );
    }


}
