package com.god.base.server.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.god.base.common.domain.Fault;
import com.god.base.common.domain.request.FaultRequest;
import com.god.base.server.mapper.FaultMapper;
import com.god.base.server.service.FaultService;
import com.god.common.core.web.page.TableDataInfo;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import java.io.Serializable;

/**
 * 故障serviceImpl
 *
 * @author ChenXinHai
 * @version 2023/11/21 - 18:34
 */

@Service
@Log4j2
public class FaultServiceImpl extends ServiceImpl<FaultMapper, Fault> implements FaultService {

    @Override
    public TableDataInfo<Fault> faultList(FaultRequest faultRequest) {
        LambdaQueryWrapper<Fault> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        Page<Fault> page = faultRequest.buildPage();
        log.info("分页查询：[{}]", JSONObject.toJSONString(page));
        Page<Fault> page1 = this.page(page, lambdaQueryWrapper);
        return TableDataInfo.<Fault>builder()
                .rows(page1.getRecords())
                .total(page1.getTotal())
                .build();
    }

    @Override
    public boolean save(Fault fault){
        boolean save = super.save(fault);
        if (!save){
            log.warn("增加故障：[/-{}-/]失败！ 请求参数:{}",
                    fault.getFaultId(),
                    JSONObject.toJSONString(fault));
            throw new RuntimeException("添加故障失败！");
        }
        return true;
    }

    @Override
    public boolean removeById(Serializable faultId){
        boolean remove = super.removeById(faultId);
        if (!remove){
            log.warn("删除故障编号:[/-{}-/]失败！",
                    faultId);
            throw new RuntimeException("删除故障失败");
        }
        return true;
    }

    @Override
    public boolean updateById(Fault fault){
        boolean update = super.updateById(fault);
        if (!update){
            log.warn("编辑故障信息:[/-{}-/未成功！]请求参数:{}",
                    fault.getFaultId(),
                    JSONObject.toJSONString(fault));
            throw new RuntimeException("编辑故障失败！");
        }
        return true;
    }


}
