package com.god.base.server.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.god.base.common.domain.Fence;
import com.god.base.common.domain.request.FenceQueryRequest;
import com.god.base.server.mapper.FenceMapper;
import com.god.base.server.service.FenceService;
import com.god.common.core.web.page.TableDataInfo;
import com.god.common.redis.service.RedisService;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.Serializable;
import java.util.Date;

/**
 * @ClassName FenceServiceImpl
 * @Author Lou-Zs
 * @Date 2023/11/19 22:26
 * @Version 1.0
 * @Description TODO
 **/

/**
 * 电子围栏
 * @author Lou-Zs
 */
@Service
@Log4j2
public class FenceServiceImpl extends ServiceImpl<FenceMapper , Fence> implements FenceService {

    //redis
    @Autowired
    private RedisService redisService;

    /**
     * 增添电子围栏
     * @param entity
     * @return
     */
    @Override
    public boolean save(Fence entity) {
        boolean save = super.save(entity);
        if (!save){
            log.warn("增加围栏:[/-{}-/]失败! 请求参数:{}",
                    entity.getFenceName(),
                    JSONObject.toJSONString(entity));
            throw new RuntimeException("增添围栏失败!");
        }
        return true;
    }

    /**
     * 根据围栏编号删除围栏
     * @param id
     * @return
     */
    @Override
    public boolean removeById(Serializable id) {
        boolean remove = super.removeById(id);
        if (!remove){
            log.warn("删除围栏编号:[/-{}-/]失败!",
                    id);
            throw new RuntimeException("删除围栏失败!");
        }
        return true;
    }

    /**
     * 根据围栏编号编辑围栏信息
     * @param entity
     * @return
     */
    @Override
    public boolean updateById(Fence entity) {
        entity.setUpdateTime(new Date());
//        获取当前围栏坐标
        String fenceLocation = entity.getFenceLocation();
//        将围栏坐标存储到redis中
//        key 围栏编号
//        value 围栏坐标信息
        redisService.setCacheObject(entity.getFenceId()+"",fenceLocation);
        boolean update = super.updateById(entity);
        if (!update){
            log.warn("编辑围栏[/-{}-/]未成功! 请求参数:{}",
                    entity.getFenceName(),
                    JSONObject.toJSONString(entity));
            throw new RuntimeException("编辑围栏失败!");
        }
        return true;
    }


    /**
     * 分页查询电子围栏列表
     * @param fenceQueryRequest
     * @return
     */
    @Override
    public TableDataInfo<Fence> fenceListAndPage(FenceQueryRequest fenceQueryRequest) {
        LambdaQueryWrapper<Fence> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        //判断查询围栏是否为空
        if (StringUtils.isNotEmpty(fenceQueryRequest.getFenceName())){
            //模糊查询
            lambdaQueryWrapper.like(Fence::getFenceName,fenceQueryRequest.getFenceName());
        }
        //判断激活状态是否为空
        if (null != fenceQueryRequest.getFenceStatus()){
            //精确查询
            lambdaQueryWrapper.eq(Fence::getFenceStatus,fenceQueryRequest.getFenceStatus());
        }
        //判断行驶状态是否为空
        if (null != fenceQueryRequest.getDriveStatus()){
            //精确查询
            lambdaQueryWrapper.eq(Fence::getDriveStatus,fenceQueryRequest.getDriveStatus());
        }
        //分页
        Page<Fence> fencePage = fenceQueryRequest.buildPage();
        log.info("分页查询:[ {} ]", JSONObject.toJSONString(fencePage));
        Page<Fence> page = this.page(fencePage, lambdaQueryWrapper);
        return TableDataInfo.<Fence>builder()
                .rows(page.getRecords())
                .total(page.getTotal())
                .build();
    }
}
