package com.god.base.server.util;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;


/**
 * aop切面 工具类
 */
@Aspect
@Component
public class AopConfig {
    //日志打印
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    ThreadLocal<Long> threadLocal = new ThreadLocal<>();

    /**
     * @Description: 定义切面的那个类
     */
    @Pointcut("execution(* com.god.base.server.controller.*.*(..))")
    public void print(){}


    @Around("print()")
    public Object LogStart(ProceedingJoinPoint proceedingJoinPoint) throws Throwable {
        threadLocal.set(System.currentTimeMillis());
        //使用ServletRequestAttributes请求上下文获取更多
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = attributes.getRequest();
        String typeName = proceedingJoinPoint.getSignature().getDeclaringTypeName();
        String name = proceedingJoinPoint.getSignature().getName();
        //使用数据来获取参数
        Object[] pointArgs = proceedingJoinPoint.getArgs();
        ObjectMapper objectMapper = new ObjectMapper();
        logger.info("—_—方—_—_—法_—_—_—启—_—_—动—_—_—开—_—_—始—_—_—希—_—_—望—_—_—无—_—_—B—_—_—U—_—_—G—_—");
        logger.info("|调用前是：    【{}】", typeName);
        logger.info("|方法名称：    【{}】", name);
        logger.info("|传递参数:     【{}】", objectMapper.writeValueAsString(objectMapper));
        logger.info("|URL:        【{}】", request.getRequestURI().toString());
        logger.info("IP:          【{}】", request.getRemoteAddr());
        logger.info("______________________________________________________________________");


        Object proceed = proceedingJoinPoint.proceed();
        logger.info("|调用前是：    【{}】", typeName);
        logger.info("|方法名称：    【{}】", name);
        logger.info("|传递参数：    【{}】", objectMapper.writeValueAsString(objectMapper));
        logger.info("|URL:        【{}】", request.getRequestURI().toString());
        logger.info("IP:          【{}】", request.getRemoteAddr());
        logger.info("|耗时：       【{}】", System.currentTimeMillis() - threadLocal.get());

        return proceed;
    }


}
