package com.god.base.server.webSocket.handler;

import com.alibaba.fastjson.JSON;
import com.god.base.server.common.domain.VehicleMessage;
import com.god.base.server.common.domainConstants.RedisConstant;
import com.god.base.server.mapper.CarMapper;
import com.god.base.server.webSocket.entity.VehicleAllData;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.websocket.Session;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;
import java.util.stream.Collectors;

/**
 * @author swh的mac
 * @Date 2023/11/20 14:37
 */
@Log4j2
@Component
public class SocketBatchHandler {
    public static CopyOnWriteArrayList<Session> sessions = new CopyOnWriteArrayList<>();

    @Autowired
    private CarMapper carMapper;

    @Autowired
    private RedisTemplate redisTemplate;

    @Scheduled(cron = "0/1 * * * * ?")
    public void sendMessageFlush(){
        for (Session session : sessions) {
            List<String> ids = carMapper.getOnlineCarIds();
            List<VehicleMessage> messages = ids.stream().map(id -> {
                VehicleMessage message = (VehicleMessage) redisTemplate.opsForValue().get(RedisConstant.CURRENT_INFO + ":" + id);
                return message;
            }).collect(Collectors.toList());
            Integer day = (Integer) redisTemplate.opsForValue().get(RedisConstant.VEHICLE_INFO_TOKEN+RedisConstant.CURRENT_DAY_FAULT);
            Integer month = (Integer) redisTemplate.opsForValue().get(RedisConstant.VEHICLE_INFO_TOKEN+RedisConstant.CURRENT_MONTH_FAULT);
            Integer onlineCount = carMapper.getOnlineCarCount();
            Integer unOnlineCount = carMapper.getUnOnlineCount();
            VehicleAllData vehicleAllData = new VehicleAllData();
            vehicleAllData.setMessages(messages);
            vehicleAllData.setInfo(day+":"+month+":"+onlineCount+":"+unOnlineCount);
            try {
                session.getBasicRemote().sendText(JSON.toJSONString(vehicleAllData));
            } catch (Exception e) {
                log.info("{}:连接中断",session.getId());
                sessions.remove(session);
            }
        }
    }
}
